@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2023 The Pion community <https://pion.ly>
+// SPDX-License-Identifier: MIT
+
 // Package main implements a CLI tool which acts as a STUN client
 package main
 
@@ -13,31 +16,40 @@ import (
 func main() {
 	flag.Usage = func() {
 		fmt.Fprintf(os.Stderr, "Usage of %s:\n", os.Args[0])
-		fmt.Fprintln(os.Stderr, os.Args[0], "stun.l.google.com:19302")
+		fmt.Fprintln(os.Stderr, os.Args[0], "stun:stun.l.google.com:19302")
 	}
 	flag.Parse()
-	addr := flag.Arg(0)
-	if addr == "" {
-		addr = "stun.l.google.com:19302"
+
+	uriStr := flag.Arg(0)
+	if uriStr == "" {
+		uriStr = "stun:stun.l.google.com:19302"
 	}
-	// we only try the first address, so restrict ourselves to IPv4
-	c, err := stun.Dial("udp4", addr)
+
+	uri, err := stun.ParseURI(uriStr)
 	if err != nil {
-		log.Fatal("dial:", err)
+		log.Fatalf("Invalid URI '%s': %s", uriStr, err)
+	}
+
+	// we only try the first address, so restrict ourselves to IPv4
+	c, err := stun.DialURI(uri, &stun.DialConfig{})
+	if err != nil {
+		log.Fatalf("Failed to dial: %s", err)
 	}
 	if err = c.Do(stun.MustBuild(stun.TransactionID, stun.BindingRequest), func(res stun.Event) {
 		if res.Error != nil {
-			log.Fatalln(res.Error)
+			log.Fatalf("Failed STUN transaction: %s", res.Error)
 		}
+
 		var xorAddr stun.XORMappedAddress
 		if getErr := xorAddr.GetFrom(res.Message); getErr != nil {
-			log.Fatalln(getErr)
+			log.Fatalf("Failed to get XOR-MAPPED-ADDRESS: %s", getErr)
 		}
-		fmt.Println(xorAddr)
+
+		log.Print(xorAddr)
 	}); err != nil {
-		log.Fatal("do:", err)
+		log.Fatal("Do:", err)
 	}
 	if err := c.Close(); err != nil {
-		log.Fatalln(err)
+		log.Fatalf("Failed to close connection: %s", err)
 	}
 }
