@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2023 The Pion community <https://pion.ly>
+// SPDX-License-Identifier: MIT
+
 // Package testutil contains helpers and utilities for writing tests
 package testutil
 
@@ -12,6 +15,6 @@ func ShouldNotAllocate(t *testing.T, f func()) {
 		return
 	}
 	if a := testing.AllocsPerRun(10, f); a > 0 {
-		t.Errorf("allocations detected: %f", a)
+		t.Errorf("Allocations detected: %f", a)
 	}
 }
