@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2023 The Pion community <https://pion.ly>
+// SPDX-License-Identifier: MIT
+
 //go:build !js
 // +build !js
 
@@ -233,7 +236,7 @@ func TestMessage_AttrSizeLessThanLength(t *testing.T) {
 
 type unexpectedEOFReader struct{}
 
-func (r unexpectedEOFReader) Read(b []byte) (int, error) {
+func (r unexpectedEOFReader) Read([]byte) (int, error) {
 	return 0, io.ErrUnexpectedEOF
 }
 
@@ -266,7 +269,7 @@ func BenchmarkMessage_WriteTo(b *testing.B) {
 	buf := new(bytes.Buffer)
 	b.ReportAllocs()
 	for i := 0; i < b.N; i++ {
-		m.WriteTo(buf) // nolint:errcheck,gosec
+		m.WriteTo(buf) //nolint:errcheck,gosec
 		buf.Reset()
 	}
 }
@@ -502,7 +505,7 @@ func TestMessage_String(t *testing.T) {
 
 func TestIsMessage(t *testing.T) {
 	m := New()
-	NewSoftware("software").AddTo(m) // nolint:errcheck,gosec
+	NewSoftware("software").AddTo(m) //nolint:errcheck,gosec
 	m.WriteHeader()
 
 	tt := [...]struct {
@@ -531,7 +534,7 @@ func BenchmarkIsMessage(b *testing.B) {
 	m := New()
 	m.Type = MessageType{Method: MethodBinding, Class: ClassRequest}
 	m.TransactionID = NewTransactionID()
-	NewSoftware("cydev/stun test").AddTo(m) // nolint:errcheck,gosec
+	NewSoftware("cydev/stun test").AddTo(m) //nolint:errcheck,gosec
 	m.WriteHeader()
 
 	b.SetBytes(int64(messageHeaderSize))
@@ -546,7 +549,7 @@ func BenchmarkIsMessage(b *testing.B) {
 
 func loadData(tb testing.TB, name string) []byte {
 	name = filepath.Join("testdata", name)
-	f, err := os.Open(name) //nolint: gosec
+	f, err := os.Open(name) //nolint:gosec
 	if err != nil {
 		tb.Fatal(err)
 	}
@@ -574,7 +577,7 @@ func TestExampleChrome(t *testing.T) {
 func TestMessageFromBrowsers(t *testing.T) {
 	// file contains udp-packets captured from browsers (WebRTC)
 	reader := csv.NewReader(bytes.NewReader(loadData(t, "frombrowsers.csv")))
-	reader.Comma = ','
+	reader.Comment = '#'
 	_, err := reader.Read() // skipping header
 	if err != nil {
 		t.Fatal("failed to skip header of csv: ", err)
@@ -634,7 +637,7 @@ func BenchmarkMessageFull(b *testing.B) {
 		}
 		m.WriteAttributes()
 		m.WriteHeader()
-		Fingerprint.AddTo(m) // nolint:errcheck,gosec
+		Fingerprint.AddTo(m) //nolint:errcheck,gosec
 		m.WriteHeader()
 		m.Reset()
 	}
@@ -688,7 +691,7 @@ func TestMessage_Contains(t *testing.T) {
 func ExampleMessage() {
 	buf := new(bytes.Buffer)
 	m := new(Message)
-	m.Build(BindingRequest, // nolint:errcheck,gosec
+	m.Build(BindingRequest, //nolint:errcheck,gosec
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
@@ -714,11 +717,11 @@ func ExampleMessage() {
 	decoded.Raw = make([]byte, 0, 1024) // for ReadFrom that reuses m.Raw
 	// ReadFrom does not allocate internal buffer for reading from io.Reader,
 	// instead it uses m.Raw, expanding it length to capacity.
-	decoded.ReadFrom(buf) // nolint:errcheck,gosec
+	decoded.ReadFrom(buf) //nolint:errcheck,gosec
 	fmt.Println("has software:", decoded.Contains(AttrSoftware))
 	fmt.Println("has nonce:", decoded.Contains(AttrNonce))
 	var software Software
-	decoded.Parse(&software) // nolint:errcheck,gosec
+	decoded.Parse(&software) //nolint:errcheck,gosec
 	// Rule for Parse method is same as for Build.
 	fmt.Println("software:", software)
 	if err := Fingerprint.Check(decoded); err == nil {
@@ -901,7 +904,7 @@ func BenchmarkMessage_CloneTo(b *testing.B) {
 	}
 	b.SetBytes(int64(len(m.Raw)))
 	a := new(Message)
-	m.CloneTo(a) // nolint:errcheck,gosec
+	m.CloneTo(a) //nolint:errcheck,gosec
 	for i := 0; i < b.N; i++ {
 		if err := m.CloneTo(a); err != nil {
 			b.Fatal(err)
@@ -930,7 +933,7 @@ func TestMessage_AddTo(t *testing.T) {
 	if b.Equal(m) {
 		t.Fatal("should not be equal")
 	}
-	m.AddTo(b) // nolint:errcheck,gosec
+	m.AddTo(b) //nolint:errcheck,gosec
 	if !b.Equal(m) {
 		t.Fatal("should be equal")
 	}
@@ -948,7 +951,7 @@ func BenchmarkMessage_AddTo(b *testing.B) {
 		b.Fatal(err)
 	}
 	a := new(Message)
-	m.CloneTo(a) // nolint:errcheck,gosec
+	m.CloneTo(a) //nolint:errcheck,gosec
 	for i := 0; i < b.N; i++ {
 		if err := m.AddTo(a); err != nil {
 			b.Fatal(err)
