@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2023 The Pion community <https://pion.ly>
+// SPDX-License-Identifier: MIT
+
 package stun
 
 import (
@@ -14,7 +17,7 @@ func TestUnknownAttributes(t *testing.T) {
 		t.Error("bad String:", a)
 	}
 	if (UnknownAttributes{}).String() != "<nil>" {
-		t.Error("bad blank stirng")
+		t.Error("bad blank string")
 	}
 	if err := a.AddTo(m); err != nil {
 		t.Error(err)
